@@ -2,12 +2,13 @@
 # -*- coding: utf-8 -*-
 
 # insert the package for universal imports.
-import os, sys, syst3m
+import os, sys
+from fil3s import *
 
 # settings.
 SOURCE_NAME = "netw0rk"
-SOURCE_PATH = syst3m.defaults.source_path(__file__, back=1)
-BASE = syst3m.defaults.source_path(SOURCE_PATH, back=1)
+SOURCE_PATH = Defaults.source_path(__file__, back=1)
+BASE = Defaults.source_path(SOURCE_PATH, back=1)
 sys.path.insert(1, BASE)
 
 # imports.
@@ -15,11 +16,11 @@ import netw0rk
 from netw0rk.classes.config import *
 
 # the cli object class.
-class CLI(cl1.CLI):
+class CLI_(CLI.CLI):
 	def __init__(self):
 		
 		# defaults.
-		cl1.CLI.__init__(self,
+		CLI.CLI.__init__(self,
 			modes={
 				"--network":"Access the network.",
 				"    --info":"Retrieve the current network information.",
@@ -57,7 +58,7 @@ class CLI(cl1.CLI):
 			# info.
 			if self.arguments.present(['--info']):
 				response = netw0rk.network.info()
-				r3sponse.log(response=response)
+				Response.log(response=response)
 				if response.success: 
 					del response["message"] ; del response["error"] ; del response["success"]
 					print("Network info:")
@@ -71,12 +72,12 @@ class CLI(cl1.CLI):
 		elif self.arguments.present(['--firewall']):
 
 			# check os.
-			syst3m.defaults.operating_system(supported=["linux"])
+			Defaults.operating_system(supported=["linux"])
 
 			# retrieve the firewall information.
 			if self.arguments.present(['--info']):
 				response = netw0rk.firewall.info()
-				r3sponse.log(response=response)
+				Response.log(response=response)
 				if response.success: 
 					del response["message"] ; del response["error"] ; del response["success"]
 					print(response.json(indent=3).replace("{\n","").replace("\n}","").replace('",',"").replace('"',"").replace('\n  ',"\n * "))
@@ -84,12 +85,12 @@ class CLI(cl1.CLI):
 			# disable the firewall.
 			elif self.arguments.present(['--disable']):
 				response = netw0rk.firewall.disable()
-				r3sponse.log(response=response)
+				Response.log(response=response)
 
 			# enable the firewall.
 			elif self.arguments.present(['--enable']):
 				response = netw0rk.firewall.enable()
-				r3sponse.log(response=response)
+				Response.log(response=response)
 
 			# set the default port action.
 			elif self.arguments.present(['--set-default']):
@@ -97,19 +98,19 @@ class CLI(cl1.CLI):
 				if deny in ["True", "true", True]: deny = True
 				else: deny = False
 				response = netw0rk.firewall.set_default(deny=deny)
-				r3sponse.log(response=response)
+				Response.log(response=response)
 
 			# allow a port.
 			elif self.arguments.present(['--allow']):
 				port = int(self.arguments.get("--allow"))
 				response = netw0rk.firewall.allow(port)
-				r3sponse.log(response=response)
+				Response.log(response=response)
 
 			# deny a port.
 			elif self.arguments.present(['--deny']):
 				port = int(self.arguments.get("--deny"))
 				response = netw0rk.firewall.deny(port)
-				r3sponse.log(response=response)
+				Response.log(response=response)
 
 
 			# invalid.
@@ -122,7 +123,7 @@ class CLI(cl1.CLI):
 	
 # main.
 if __name__ == "__main__":
-	cli = CLI()
+	cli = CLI_()
 	if "--developer" in sys.argv:
 		cli.start()
 	else:
