@@ -5,15 +5,14 @@
 import os, sys, ast, json, glob, platform, subprocess, random, requests, socket, time
 
 # inc imports.
-import syst3m, cl1
+import syst3m
 from fil3s import *
-from r3sponse import r3sponse
 
 # source.
 ALIAS = "netw0rk"
-SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
-OS = syst3m.defaults.operating_system(supported=["macos", "linux"])
-syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
+SOURCE_PATH = Defaults.source_path(__file__, back=3)
+OS = Defaults.operating_system(supported=["macos", "linux"])
+Defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal variables.
 OWNER = os.environ.get("USER")
